==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/WebPubSubSharedPrivateLinkResource.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin

import com.pulumi.azurenative.webpubsub.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.webpubsub.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebPubSubSharedPrivateLinkResource].
 */
@PulumiTagMarker
public class WebPubSubSharedPrivateLinkResourceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebPubSubSharedPrivateLinkResourceArgs = WebPubSubSharedPrivateLinkResourceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebPubSubSharedPrivateLinkResourceArgsBuilder.() -> Unit) {
        val builder = WebPubSubSharedPrivateLinkResourceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WebPubSubSharedPrivateLinkResource {
        val builtJavaResource =
            com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebPubSubSharedPrivateLinkResource(builtJavaResource)
    }
}

/**
 * Describes a Shared Private Link Resource
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2021-04-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-06-01-preview, 2023-08-01-preview.
 * ## Example Usage
 * ### WebPubSubSharedPrivateLinkResources_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webPubSubSharedPrivateLinkResource = new AzureNative.WebPubSub.WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", new()
 *     {
 *         GroupId = "sites",
 *         PrivateLinkResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp",
 *         RequestMessage = "Please approve",
 *         ResourceGroupName = "myResourceGroup",
 *         ResourceName = "myWebPubSubService",
 *         SharedPrivateLinkResourceName = "upstream",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/webpubsub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := webpubsub.NewWebPubSubSharedPrivateLinkResource(ctx, "webPubSubSharedPrivateLinkResource", &webpubsub.WebPubSubSharedPrivateLinkResourceArgs{
 * 			GroupId:                       pulumi.String("sites"),
 * 			PrivateLinkResourceId:         pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp"),
 * 			RequestMessage:                pulumi.String("Please approve"),
 * 			ResourceGroupName:             pulumi.String("myResourceGroup"),
 * 			ResourceName:                  pulumi.String("myWebPubSubService"),
 * 			SharedPrivateLinkResourceName: pulumi.String("upstream"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webPubSubSharedPrivateLinkResource = new WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", WebPubSubSharedPrivateLinkResourceArgs.builder()
 *             .groupId("sites")
 *             .privateLinkResourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp")
 *             .requestMessage("Please approve")
 *             .resourceGroupName("myResourceGroup")
 *             .resourceName("myWebPubSubService")
 *             .sharedPrivateLinkResourceName("upstream")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:webpubsub:WebPubSubSharedPrivateLinkResource upstream /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.SignalRService/webPubSub/{resourceName}/sharedPrivateLinkResources/{sharedPrivateLinkResourceName}
 * ```
 */
public class WebPubSubSharedPrivateLinkResource internal constructor(
    override val javaResource: com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource,
) : KotlinCustomResource(javaResource, WebPubSubSharedPrivateLinkResourceMapper) {
    /**
     * The group id from the provider of resource the shared private link resource is for
     */
    public val groupId: Output<String>
        get() = javaResource.groupId().applyValue({ args0 -> args0 })

    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The resource id of the resource the shared private link resource is for
     */
    public val privateLinkResourceId: Output<String>
        get() = javaResource.privateLinkResourceId().applyValue({ args0 -> args0 })

    /**
     * Provisioning state of the resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The request message for requesting approval of the shared private link resource
     */
    public val requestMessage: Output<String>?
        get() = javaResource.requestMessage().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Status of the shared private link resource
     */
    public val status: Output<String>
        get() = javaResource.status().applyValue({ args0 -> args0 })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource - e.g. "Microsoft.SignalRService/SignalR"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebPubSubSharedPrivateLinkResourceMapper :
    ResourceMapper<WebPubSubSharedPrivateLinkResource> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource::class == javaResource::class

    override fun map(javaResource: Resource): WebPubSubSharedPrivateLinkResource =
        WebPubSubSharedPrivateLinkResource(
            javaResource as
                com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource,
        )
}

/**
 * @see [WebPubSubSharedPrivateLinkResource].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebPubSubSharedPrivateLinkResource].
 */
public suspend fun webPubSubSharedPrivateLinkResource(
    name: String,
    block: suspend WebPubSubSharedPrivateLinkResourceResourceBuilder.() -> Unit,
):
    WebPubSubSharedPrivateLinkResource {
    val builder = WebPubSubSharedPrivateLinkResourceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebPubSubSharedPrivateLinkResource].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webPubSubSharedPrivateLinkResource(name: String): WebPubSubSharedPrivateLinkResource {
    val builder = WebPubSubSharedPrivateLinkResourceResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/WebPubSubSharedPrivateLinkResource.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin

import com.pulumi.azurenative.webpubsub.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.webpubsub.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebPubSubSharedPrivateLinkResource].
 */
@PulumiTagMarker
public class WebPubSubSharedPrivateLinkResourceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebPubSubSharedPrivateLinkResourceArgs = WebPubSubSharedPrivateLinkResourceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebPubSubSharedPrivateLinkResourceArgsBuilder.() -> Unit) {
        val builder = WebPubSubSharedPrivateLinkResourceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebPubSubSharedPrivateLinkResource {
        val builtJavaResource =
            com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebPubSubSharedPrivateLinkResource(builtJavaResource)
    }
}

/**
 * Describes a Shared Private Link Resource
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2021-04-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-06-01-preview, 2023-08-01-preview, 2024-01-01-preview.
 * ## Example Usage
 * ### WebPubSubSharedPrivateLinkResources_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webPubSubSharedPrivateLinkResource = new AzureNative.WebPubSub.WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", new()
 *     {
 *         GroupId = "sites",
 *         PrivateLinkResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp",
 *         RequestMessage = "Please approve",
 *         ResourceGroupName = "myResourceGroup",
 *         ResourceName = "myWebPubSubService",
 *         SharedPrivateLinkResourceName = "upstream",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/webpubsub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := webpubsub.NewWebPubSubSharedPrivateLinkResource(ctx, "webPubSubSharedPrivateLinkResource", &webpubsub.WebPubSubSharedPrivateLinkResourceArgs{
 * 			GroupId:                       pulumi.String("sites"),
 * 			PrivateLinkResourceId:         pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp"),
 * 			RequestMessage:                pulumi.String("Please approve"),
 * 			ResourceGroupName:             pulumi.String("myResourceGroup"),
 * 			ResourceName:                  pulumi.String("myWebPubSubService"),
 * 			SharedPrivateLinkResourceName: pulumi.String("upstream"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webPubSubSharedPrivateLinkResource = new WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", WebPubSubSharedPrivateLinkResourceArgs.builder()
 *             .groupId("sites")
 *             .privateLinkResourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp")
 *             .requestMessage("Please approve")
 *             .resourceGroupName("myResourceGroup")
 *             .resourceName("myWebPubSubService")
 *             .sharedPrivateLinkResourceName("upstream")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:webpubsub:WebPubSubSharedPrivateLinkResource upstream /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.SignalRService/webPubSub/{resourceName}/sharedPrivateLinkResources/{sharedPrivateLinkResourceName}
 * ```
 */
public class WebPubSubSharedPrivateLinkResource internal constructor(
    override val javaResource: com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource,
) : KotlinCustomResource(javaResource, WebPubSubSharedPrivateLinkResourceMapper) {
    /**
     * The group id from the provider of resource the shared private link resource is for
     */
    public val groupId: Output<String>
        get() = javaResource.groupId().applyValue({ args0 -> args0 })

    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The resource id of the resource the shared private link resource is for
     */
    public val privateLinkResourceId: Output<String>
        get() = javaResource.privateLinkResourceId().applyValue({ args0 -> args0 })

    /**
     * Provisioning state of the resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The request message for requesting approval of the shared private link resource
     */
    public val requestMessage: Output<String>?
        get() = javaResource.requestMessage().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Status of the shared private link resource
     */
    public val status: Output<String>
        get() = javaResource.status().applyValue({ args0 -> args0 })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource - e.g. "Microsoft.SignalRService/SignalR"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebPubSubSharedPrivateLinkResourceMapper :
    ResourceMapper<WebPubSubSharedPrivateLinkResource> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource::class == javaResource::class

    override fun map(javaResource: Resource): WebPubSubSharedPrivateLinkResource =
        WebPubSubSharedPrivateLinkResource(
            javaResource as
                com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource,
        )
}

/**
 * @see [WebPubSubSharedPrivateLinkResource].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebPubSubSharedPrivateLinkResource].
 */
public suspend fun webPubSubSharedPrivateLinkResource(
    name: String,
    block: suspend WebPubSubSharedPrivateLinkResourceResourceBuilder.() -> Unit,
):
    WebPubSubSharedPrivateLinkResource {
    val builder = WebPubSubSharedPrivateLinkResourceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebPubSubSharedPrivateLinkResource].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webPubSubSharedPrivateLinkResource(name: String): WebPubSubSharedPrivateLinkResource {
    val builder = WebPubSubSharedPrivateLinkResourceResourceBuilder()
    builder.name(name)
    return builder.build()
}
